import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import { prop, withProp } from 'styled-tools';
import { a as as, b as classCallCheck, c as inherits, d as objectWithoutProperties, e as possibleConstructorReturn, f as _extends } from './as-fe550043.js';
import Base from './Base.js';
import { a as numberToPx } from './chunk-84d8695a.js';
import { findDOMNode } from 'react-dom';
import { a as callAll } from './chunk-fa81e9f1.js';
import 'lodash-es/uniq';
import 'react-known-props';
import 'lodash-es/omit';
import './chunk-a29c7f2d.js';
import 'lodash-es/kebabCase';

var Component = function Component(props) {
  return React.createElement(Base, _extends({
    "aria-orientation": props.vertical ? "vertical" : "horizontal"
  }, props));
};

var Toolbar = styled(Component).withConfig({
  displayName: "Toolbar"
})(["position:relative;display:grid;width:100%;padding:", ";grid-gap:", ";grid-template:\"start center end\" / 1fr auto 1fr;&[aria-orientation=\"vertical\"]{width:min-content;height:100%;grid-template:\"start\" 1fr \"center\" auto \"end\" 1fr;}", ";"], withProp("gutter", numberToPx), withProp("gutter", numberToPx), prop("theme.Toolbar"));

Toolbar.propTypes = {
  gutter: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  vertical: PropTypes.bool
};

Toolbar.defaultProps = {
  role: "toolbar",
  gutter: 8
};

var Toolbar$1 = as("div")(Toolbar);

var Component$1 = function (_React$Component) {
  inherits(Component, _React$Component);

  function Component(props) {
    classCallCheck(this, Component);

    var _this = possibleConstructorReturn(this, _React$Component.call(this, props));

    _this.getInitialTabIndex = function () {
      var tabIndex = _this.props.tabIndex;

      return typeof tabIndex !== "undefined" ? tabIndex : -1;
    };

    _this.getElement = function () {
      if (typeof _this.element === "undefined") {
        _this.element = findDOMNode(_this);
      }
      return _this.element;
    };

    _this.getToolbar = function () {
      if (typeof _this.toolbar === "undefined") {
        _this.toolbar = _this.getElement().closest("." + Toolbar$1.styledComponentId);
      }
      return _this.toolbar;
    };

    _this.getFocusables = function () {
      if (!_this.getToolbar()) return [];
      return _this.getToolbar().querySelectorAll("." + ToolbarFocusable.styledComponentId);
    };

    _this.getCurrentIndex = function (focusables) {
      var currentIndex = -1;
      focusables.forEach(function (item, i) {
        if (item === _this.getElement()) {
          currentIndex = i;
        }
      });
      return currentIndex;
    };

    _this.getNextFocusable = function (focusables, currentIndex) {
      var index = currentIndex + 1;
      return focusables.item(index) || focusables.item(0);
    };

    _this.getPreviousFocusable = function (focusables, currentIndex) {
      var index = currentIndex ? currentIndex - 1 : focusables.length - 1;
      return focusables.item(index);
    };

    _this.toolbarIsVertical = function () {
      if (!_this.getToolbar()) return false;
      return _this.getToolbar().getAttribute("aria-orientation") === "vertical";
    };

    _this.addKeyDownHandler = function () {
      if (!_this.getToolbar()) return;
      _this.getElement().addEventListener("keydown", _this.handleKeyDown);
    };

    _this.removeKeyDownHandler = function () {
      if (!_this.getToolbar()) return;
      _this.getElement().removeEventListener("keydown", _this.handleKeyDown);
    };

    _this.handleKeyDown = function (e) {
      var isVertical = _this.toolbarIsVertical();
      var nextKey = isVertical ? "ArrowDown" : "ArrowRight";
      var previousKey = isVertical ? "ArrowUp" : "ArrowLeft";
      var willPerformEvent = [nextKey, previousKey].indexOf(e.key) >= 0;

      if (!willPerformEvent) return;

      var focusables = _this.getFocusables();
      var currentIndex = _this.getCurrentIndex(focusables);

      e.preventDefault();
      _this.setState({ tabIndex: _this.getInitialTabIndex() });

      if (e.key === nextKey) {
        _this.getNextFocusable(focusables, currentIndex).focus();
      } else {
        _this.getPreviousFocusable(focusables, currentIndex).focus();
      }
    };

    _this.handleFocus = function () {
      _this.setState({ tabIndex: 0 });
    };

    _this.state = {
      tabIndex: _this.getInitialTabIndex()
    };
    return _this;
  }

  Component.prototype.componentDidMount = function componentDidMount() {
    if (this.getCurrentIndex(this.getFocusables()) === 0) {
      this.setState({ tabIndex: 0 });
    }

    if (!this.props.disabled) {
      this.addKeyDownHandler();
    }
  };

  Component.prototype.componentDidUpdate = function componentDidUpdate(prevProps) {
    var disabled = this.props.disabled;


    if (prevProps.disabled !== disabled) {
      if (disabled) {
        this.removeKeyDownHandler();
      } else {
        this.addKeyDownHandler();
      }
    }
  };

  Component.prototype.componentWillUnmount = function componentWillUnmount() {
    this.removeKeyDownHandler();
  };

  Component.prototype.render = function render() {
    return React.createElement(Base, _extends({}, this.props, {
      onFocus: callAll(this.handleFocus, this.props.onFocus),
      tabIndex: this.state.tabIndex
    }));
  };

  return Component;
}(React.Component);

Component$1.propTypes = {
  tabIndex: PropTypes.number,
  onFocus: PropTypes.func,
  disabled: PropTypes.bool
};


var ToolbarFocusable = styled(Component$1).withConfig({
  displayName: "ToolbarFocusable"
})(["", ";"], prop("theme.ToolbarFocusable"));

var ToolbarFocusable$1 = as("div")(ToolbarFocusable);

var ToolbarContent = styled(Base).withConfig({
  displayName: "ToolbarContent"
})(["display:grid;grid-auto-flow:column;grid-auto-columns:min-content;grid-gap:inherit;grid-area:", ";justify-content:", ";align-items:center;[aria-orientation=\"vertical\"] > &{grid-auto-flow:row;grid-auto-rows:min-content;justify-content:initial;align-content:", ";}", ";"], prop("align"), prop("align"), prop("align"), prop("theme.ToolbarContent"));

ToolbarContent.propTypes = {
  align: PropTypes.oneOf(["start", "center", "end"])
};

ToolbarContent.defaultProps = {
  align: "start"
};

var ToolbarContent$1 = as("div")(ToolbarContent);

Toolbar$1.Focusable = ToolbarFocusable$1;
Toolbar$1.Content = ToolbarContent$1;

export default Toolbar$1;
